==> download.php?FileName=terralib-5.2.1-ubuntu-14.04.tar.gz: opt/terralib/5.2.1/3rdparty/include/terralib/terraprint_version.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/terraprint_version.h

  \brief System versioning macros.
*/

#ifndef __TERRAPRINT_INTERNAL_TERRAPRINT_VERSION_H__
#define __TERRAPRINT_INTERNAL_TERRAPRINT_VERSION_H__

/*!
  \def TERRALIB_LAYOUT_VERSION_MAJOR

  \brief Major version of TerraPrint (or version).
 */
#define TERRALIB_LAYOUT_VERSION_MAJOR 1

/*!
  \def TERRALIB_LAYOUT_VERSION_MINOR

  \brief Minor version of TerraPrint (or revision). 
 */
#define TERRALIB_LAYOUT_VERSION_MINOR 1

/*!
  \def TERRALIB_LAYOUT_VERSION_PATCH

  \brief Patched version of TerraPrint (or patch).
 */
#define TERRALIB_LAYOUT_VERSION_PATCH 0

/*!
  \def TERRALIB_LAYOUT_VERSION_STRING

  \brief This flag is used for versioning the TerraPrint code. If you have plugins and other tools
         that must check the TerraPrint version, you can test against this string.
 */
#define TERRALIB_LAYOUT_VERSION_STRING "1.1.0"

/*!
  \def TERRALIB_LAYOUT_VERSION

  \brief This flag is used for versioning the TerraPrint code. If you have plugins and other tools
         that must check the TerraPrint version, you can test against this number.
 */
#define TERRALIB_LAYOUT_VERSION 0x010100

#endif  // __TERRAPRINT_INTERNAL_TERRAPRINT_VERSION_H__

==> download.php?FileName=terralib-5.2.2-ubuntu-16.04.tar.gz: opt/terralib/5.2.2/3rdparty/include/terralib/terraprint_version.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/terraprint_version.h

  \brief System versioning macros.
*/

#ifndef __TERRALIB_LAYOUT_INTERNAL_LAYOUT_VERSION_H
#define __TERRALIB_LAYOUT_INTERNAL_LAYOUT_VERSION_H

/*!
  \def TERRALIB_LAYOUT_VERSION_MAJOR

  \brief Major version of TerraPrint (or version).
 */
#define TERRALIB_LAYOUT_VERSION_MAJOR 1

/*!
  \def TERRALIB_LAYOUT_VERSION_MINOR

  \brief Minor version of TerraPrint (or revision). 
 */
#define TERRALIB_LAYOUT_VERSION_MINOR 1

/*!
  \def TERRALIB_LAYOUT_VERSION_PATCH

  \brief Patched version of TerraPrint (or patch).
 */
#define TERRALIB_LAYOUT_VERSION_PATCH 0

/*!
  \def TERRALIB_LAYOUT_VERSION_STRING

  \brief This flag is used for versioning the TerraPrint code. If you have plugins and other tools
         that must check the TerraPrint version, you can test against this string.
 */
#define TERRALIB_LAYOUT_VERSION_STRING "1.1.0"

/*!
  \def TERRALIB_LAYOUT_VERSION

  \brief This flag is used for versioning the TerraPrint code. If you have plugins and other tools
         that must check the TerraPrint version, you can test against this number.
 */
#define TERRALIB_LAYOUT_VERSION 0x010100

#endif  // __TERRAPRINT_INTERNAL_TERRAPRINT_VERSION_H__
